==> poedit_3.2.2.orig.tar.gz: poedit-3.2.2/src/gexecute.h <==
/*
 *  This file is part of Poedit (https://poedit.net)
 *
 *  Copyright (C) 2000-2022 Vaclav Slavik
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a
 *  copy of this software and associated documentation files (the "Software"),
 *  to deal in the Software without restriction, including without limitation
 *  the rights to use, copy, modify, merge, publish, distribute, sublicense,
 *  and/or sell copies of the Software, and to permit persons to whom the
 *  Software is furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in
 *  all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 *  DEALINGS IN THE SOFTWARE.
 *
 */

#ifndef _GEXECUTE_H_
#define _GEXECUTE_H_

#include <wx/string.h>
#include <vector>


struct GettextError
{
    int line;
    wxString text;
};

typedef std::vector<GettextError> GettextErrors;


/** Executes command. Writes stderr output to \a stderrOutput if not NULL,
    and logs it with wxLogError otherwise.
    \return true if program exited with exit code 0, false otherwise.
 */
extern bool ExecuteGettext(const wxString& cmdline);

/// Like ExecuteGettext(), but stores error output parsed into per-item entries.
extern bool ExecuteGettextAndParseOutput(const wxString& cmdline,
                                         GettextErrors& errors);

extern wxString QuoteCmdlineArg(const wxString& s);

extern wxString GetGettextPackagePath();

#endif // _GEXECUTE_H_

==> poedit-3.5.2.tar.gz: poedit-3.5.2/src/gexecute.h <==
/*
 *  This file is part of Poedit (https://poedit.net)
 *
 *  Copyright (C) 2000-2024 Vaclav Slavik
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a
 *  copy of this software and associated documentation files (the "Software"),
 *  to deal in the Software without restriction, including without limitation
 *  the rights to use, copy, modify, merge, publish, distribute, sublicense,
 *  and/or sell copies of the Software, and to permit persons to whom the
 *  Software is furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in
 *  all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 *  DEALINGS IN THE SOFTWARE.
 *
 */

#ifndef _GEXECUTE_H_
#define _GEXECUTE_H_

#include <wx/string.h>
#include <vector>


struct GettextError
{
    int line;
    wxString text;
};

typedef std::vector<GettextError> GettextErrors;


/** Executes command. Writes stderr output to \a stderrOutput if not NULL,
    and logs it with wxLogError otherwise.
    \return true if program exited with exit code 0, false otherwise.
 */
extern bool ExecuteGettext(const wxString& cmdline);

/// Like ExecuteGettext(), but stores error output parsed into per-item entries.
extern bool ExecuteGettextAndParseOutput(const wxString& cmdline,
                                         GettextErrors& errors);

extern wxString QuoteCmdlineArg(const wxString& s);

#if defined(__WXOSX__) || defined(__WXMSW__)
extern wxString GetGettextPackagePath();
extern wxString GetGettextBinaryPath(const wxString& program);
#endif

#endif // _GEXECUTE_H_
